@@ -50,18 +50,14 @@ class SoftwarePilot:
 			the drone object
 		'''
 	
-		try:
-			if drone_type in self.drone_lib_dict.keys():
-				drone_type = self.drone_lib_dict[drone_type]
-				drone_lib = importlib.import_module("SoftwarePilot." + drone_type)
-			else:	
-				drone_lib = importlib.import_module(drone_type)
-			drone_call = getattr(drone_lib, drone_type)
-			drone = drone_call(connection_method, download_dir="None")
-			return drone
-		except:
-			print (f"ModuleError: Invalid drone module '{drone_type}'")
-			return None
+		if drone_type in self.drone_lib_dict.keys():
+			drone_type = self.drone_lib_dict[drone_type]
+			drone_lib = importlib.import_module("SoftwarePilot." + drone_type)
+		else:	
+			drone_lib = importlib.import_module(drone_type)
+		drone_call = getattr(drone_lib, drone_type)
+		drone = drone_call(connection_method, download_dir="None")
+		return drone
 	
 	def setup_docker(self):
 		'''
